@@ -1,4 +1,4 @@
-__version__ = '0.2.11'
+__version__ = '0.2.14'
 # Copyright (c) 2013. SlickLog.
 __author__ = 'Torindo Nesci'
 
@@ -24,6 +24,7 @@ __LOGFILE = "logfile"
 __VERBOSE = "verbose"
 __FUZZY_ROTATION = "fuzzy_rotation"
 __SUPPRESS_PRINT = "suppress_print"
+__CHARTSET = "charset"
 
 __TOOL_DESCRIPTION = """\
 version {0}
@@ -124,9 +125,11 @@ def main():
   parser.add_argument('--' + __CONFIG_FILE, help=__CONFIG_FILE_DESCRIPTION)
   parser.add_argument('--' + __FUZZY_ROTATION, default=False, action='store_true',
                       help='Use fuzzy logic to detect the rotated file.')
+  parser.add_argument('--' + __CHARTSET, default='utf-8',
+                      help='Log file charset. Default is utf-8.')
   parser.add_argument('--' + __SUPPRESS_PRINT, default=False, action='store_true',
                       help='Suppress the print of the appended data to the log file.')
-  parser.add_argument('--' + __VERBOSE, default=False, action='store_true', help='Verbose mode.')
+  parser.add_argument('-v', '--' + __VERBOSE, default=False, action='store_true', help='Verbose mode.')
   args = parser.parse_args()
 
   if not os.path.isfile(args.logfile):
@@ -143,6 +146,7 @@ def main():
   print('  {0} => {1}'.format(__SLICKLOG_LOG_NAME, log_name))
   print('  {0} => {1}'.format(__SUPPRESS_PRINT, args.suppress_print))
   print('  {0} => {1}'.format(__FUZZY_ROTATION, args.fuzzy_rotation))
+  print('  {0} => {1}'.format(__CHARTSET, args.charset))
   print('  {0} => {1}'.format(__VERBOSE, args.verbose))
 
   signal.signal(signal.SIGINT, _signal_handler)
@@ -154,7 +158,8 @@ def main():
       log_name,
       endpoint,
       args.suppress_print,
-      args.fuzzy_rotation)
+      args.fuzzy_rotation,
+      args.charset)
 
 
 def _signal_handler(signal, frame):
